* { box-sizing: border-box; }
body {
    font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
    max-width: 960px;
    margin: 0 auto;
    padding: 10px 20px 15px 20px;
    background: #f5f5f5;
    color: #333;
    font-size: 16px;
    line-height: 1.5;
}
a { color: #0066cc; text-decoration: none; }
a:hover { text-decoration: underline; }

.ownmail-header {
    display: flex;
    align-items: baseline;
    gap: 8px;
    margin-bottom: 10px;
}
.ownmail-header h1 { margin: 0; font-size: 1.5em; }
.ownmail-header h1 a { color: inherit; text-decoration: none; }
.ownmail-header h1 a:hover { text-decoration: none; }

/* Hamburger menu */
.ownmail-hamburger { position: relative; }
.ownmail-hamburger-btn {
    background: none;
    border: none;
    cursor: pointer;
    font-size: 1.8em;
    padding: 2px 4px;
    line-height: 1;
    color: inherit;
    opacity: 0.6;
    transition: opacity 0.15s;
}
.ownmail-hamburger-btn:hover { opacity: 1; }
.ownmail-hamburger-dropdown {
    display: none;
    position: absolute;
    left: 0;
    top: 100%;
    background: white;
    border: 1px solid #ddd;
    border-radius: 8px;
    box-shadow: 0 2px 10px rgba(0,0,0,0.15);
    min-width: 200px;
    z-index: 200;
    overflow: hidden;
    padding: 6px 0;
    margin-top: 8px;
}
.ownmail-hamburger-dropdown.ownmail-show { display: block; }
.ownmail-hamburger-info {
    display: block;
    padding: 8px 14px;
    font-size: 0.85em;
    color: #888;
}
.ownmail-hamburger-dropdown a {
    display: block;
    padding: 8px 14px;
    text-decoration: none;
    color: #333;
    font-size: 14px;
    transition: background-color 0.15s ease;
}
.ownmail-hamburger-dropdown a:hover { background: #f5f5f5; text-decoration: none; }
.ownmail-hamburger-divider {
    border: none;
    border-top: 1px solid #e0e0e0;
    margin: 4px 0;
}
.ownmail-hamburger-theme {
    display: flex !important;
    align-items: center;
    gap: 8px;
}
.ownmail-stats { color: #666; font-size: 0.9em; }
.ownmail-stats a { color: #0066cc; text-decoration: none; }
.ownmail-stats a:hover { text-decoration: underline; }
.ownmail-icon-link:hover { text-decoration: none !important; }
.ownmail-sticky-header {
    position: sticky;
    top: 0;
    background: #f5f5f5;
    z-index: 100;
    padding: 10px 20px 5px 20px;
    margin: -10px -20px 0 -20px;
}
.ownmail-search-form {
    display: flex;
    gap: 10px;
    margin-bottom: 10px;
}
.ownmail-search-form input[type="text"] {
    flex: 1;
    padding: 10px 15px;
    font-size: 16px;
    border: 1px solid #ddd;
    border-radius: 5px;
}
.ownmail-search-form button {
    padding: 10px 20px;
    font-size: 16px;
    background: #0066cc;
    color: white;
    border: none;
    border-radius: 5px;
    cursor: pointer;
}
.ownmail-search-form button:hover { background: #0052a3; }
.ownmail-sort-select {
    padding: 10px 15px;
    font-size: 16px;
    border: 1px solid #ddd;
    border-radius: 5px;
    background: white;
    cursor: pointer;
}
.ownmail-email-list {
    list-style: none;
    margin: 0;
    padding: 0;
    width: 100%;
    background: white;
    border-radius: 5px;
    overflow: hidden;
    border: 1px solid #ddd;
}
.ownmail-email-row {
    border-bottom: 1px solid #eee;
}
.ownmail-email-row:last-child { border-bottom: none; }
.ownmail-email-row:hover { background: #f8f9fa; }
.ownmail-email-row-link {
    display: flex;
    align-items: center;
    padding: 10px 12px;
    color: inherit;
    text-decoration: none;
    cursor: pointer;
}
.ownmail-email-row-link:hover { text-decoration: none; }
.ownmail-email-sender {
    flex: 0 0 200px;
    max-width: 200px;
    padding-right: 16px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}
.ownmail-email-row-content {
    flex: 1 1 auto;
    min-width: 0;
    display: flex;
    overflow: hidden;
}
.ownmail-email-subject {
    flex-shrink: 1;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    color: #333;
}
.ownmail-email-snippet {
    flex-shrink: 1000000;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    color: #999;
}
.ownmail-email-snippet::before { content: '\00a0–\00a0'; color: #999; }
.ownmail-email-date {
    flex: 0 0 auto;
    text-align: right;
    color: #555;
    font-size: 0.85em;
    padding-left: 16px;
    white-space: nowrap;
}
.ownmail-help { font-size: 0.8em; color: #888; margin-bottom: 15px; }
.ownmail-help code { background: #e8e8e8; padding: 2px 5px; border-radius: 3px; font-size: 0.95em; }
.ownmail-help a { color: #0066cc; text-decoration: none; }
.ownmail-help a:hover { text-decoration: underline; }
.ownmail-search-error {
    background: #ffeaea;
    border: 1px solid #ffcccc;
    color: #cc0000;
    padding: 15px;
    border-radius: 5px;
    margin-bottom: 15px;
}
.ownmail-search-error code { background: #ffdddd; padding: 2px 5px; border-radius: 3px; }
.ownmail-no-results { text-align: center; padding: 40px; color: #666; }
.ownmail-pagination {
    display: flex;
    gap: 15px;
    align-items: center;
    white-space: nowrap;
}
.ownmail-pagination a {
    color: #0066cc;
    text-decoration: none;
}
.ownmail-pagination a:hover { text-decoration: underline; }
.ownmail-pagination .ownmail-current { color: #666; }
.ownmail-pagination-bottom {
    margin-top: 10px;
    font-size: 0.85em;
    color: #666;
    justify-content: flex-end;
}
.ownmail-results-header {
    display: flex;
    justify-content: space-between;
    align-items: end;
    font-size: 0.85em;
    color: #666;
    margin-bottom: 5px;
}
.ownmail-results-header p { margin: 0; }
.ownmail-email-detail, .ownmail-help-page, .ownmail-settings-page {
    background: white;
    border: 1px solid #ddd;
    border-radius: 5px;
    padding: 15px;
    margin-bottom: 10px;
    overflow: hidden;
}
.ownmail-email-header { padding-bottom: 10px; margin-bottom: 0; }
.ownmail-email-header-top { display: flex; justify-content: space-between; align-items: flex-start; gap: 10px; }
.ownmail-email-header-top h2 { margin: 0 0 10px 0; font-size: 1.3em; flex: 1; }
.ownmail-email-header-row { margin: 6px 0; font-size: 0.9em; display: grid; grid-template-columns: 50px 1fr; }
.ownmail-email-header-top + .ownmail-email-header-row { margin-top: 4px; }
.ownmail-email-header-label { color: #666; }
.ownmail-email-header-value { word-break: break-word; }

/* Three-dot menu */
.ownmail-email-menu { position: relative; margin-top: -4px; }
.ownmail-email-menu-btn {
    background: none;
    border: none;
    cursor: pointer;
    padding: 0;
    border-radius: 50%;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    gap: 3px;
    height: 32px;
    width: 32px;
    rotate: 90deg;
}
.ownmail-email-menu-btn span {
    display: block;
    width: 3px;
    height: 3px;
    background: #666;
    border-radius: 50%;
}
.ownmail-email-menu-btn:hover { background: #f0f0f0; }
.ownmail-email-menu-dropdown {
    display: none;
    position: absolute;
    right: 0;
    top: 100%;
    background: white;
    border: 1px solid #ddd;
    border-radius: 8px;
    box-shadow: 0 2px 10px rgba(0,0,0,0.15);
    min-width: 160px;
    z-index: 100;
    overflow: hidden;
    padding: 6px 0;
}
.ownmail-email-menu-dropdown.ownmail-show { display: block; }
.ownmail-email-menu-dropdown a {
    display: block;
    padding: 8px 14px;
    text-decoration: none;
    color: #333;
    font-size: 14px;
    transition: background-color 0.25s ease;
}
.ownmail-email-menu-dropdown a:hover { background: #f5f5f5; }
.ownmail-email-menu-divider {
    border: none;
    border-top: 1px solid #e0e0e0;
    margin: 4px 0;
}
.ownmail-clickable-header { color: #0066cc; text-decoration: none; }
.ownmail-clickable-header:hover { text-decoration: underline; }
.ownmail-labels { margin-top: 10px; }
.ownmail-label {
    display: inline-block;
    background: #e8f0fe;
    color: #1a73e8;
    padding: 3px 8px;
    border-radius: 3px;
    font-size: 0.8em;
    margin-right: 5px;
    margin-bottom: 5px;
    text-decoration: none;
}
.ownmail-label:hover { background: #d2e3fc; text-decoration: none; }
.ownmail-clickable-label { cursor: pointer; }
.ownmail-email-content-area {
    background: white;
    margin: -15px;
    margin-top: 0;
    padding: 0;
    border-radius: 0 0 5px 5px;
    display: flow-root;
    overflow: hidden;
}
#ownmail-email-content {
    min-height: 200px;
    overflow: auto;
    overflow-wrap: break-word;
    word-wrap: break-word;
    font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
}
.ownmail-email-content-padded, .ownmail-email-content-plain {
    padding: 15px;
}
.ownmail-email-body { font-family: inherit; margin: 0; line-height: 1.6; }
.ownmail-email-body a { color: #0066cc; text-decoration: none; }
.ownmail-email-body a:hover { text-decoration: underline; }
.ownmail-email-body .ownmail-email-header-label { font-weight: 600; color: #666; }
.ownmail-email-body .ownmail-quote-level { margin: 0; }
.ownmail-email-body .ownmail-quote-level a { color: inherit; }
.ownmail-email-body .ownmail-quote-content { white-space: pre-wrap; }
.ownmail-email-body > div { white-space: pre-wrap; }
.ownmail-attachments { margin-top: 15px; padding-top: 15px; border-top: 1px solid #eee; }
.ownmail-attachments h4 { margin: 0 0 10px 0; font-size: 0.95em; }
.ownmail-attachment-list { list-style: none; padding: 0; margin: 0; }
.ownmail-attachment-item { padding: 8px 0; border-bottom: 1px solid #f0f0f0; }
.ownmail-attachment-item:last-child { border-bottom: none; }
.ownmail-attachment-item a { color: #0066cc; text-decoration: none; }
.ownmail-attachment-item a:hover { text-decoration: underline; }
.ownmail-help-page h2 { margin-top: 0; }
.ownmail-help-page h3 { margin-top: 15px; margin-bottom: 10px; font-size: 1.1em; color: #333; }
.ownmail-help-table { width: 100%; border-collapse: collapse; font-size: 0.9em; }
.ownmail-help-table td { padding: 8px; border-bottom: 1px solid #eee; }
.ownmail-help-table td:first-child { width: 40%; font-family: monospace; background: #f8f8f8; }

/* Settings page */
.ownmail-settings-page { max-width: 700px; margin: 0 auto; }
.ownmail-settings-page h2 { margin-top: 0; }
.ownmail-settings-config-path { font-size: 0.85em; color: #888; margin-bottom: 15px; }
.ownmail-settings-config-path code { background: #f5f5f5; padding: 2px 6px; border-radius: 3px; }
.ownmail-settings-form { display: flex; flex-direction: column; gap: 10px; }
.ownmail-settings-section {
    border: 1px solid #ddd;
    border-radius: 6px;
    padding: 15px;
    margin-bottom: 0;
}
.ownmail-settings-section legend {
    font-weight: 600;
    font-size: 1.05em;
    padding: 0 8px;
}
.ownmail-settings-field { margin-bottom: 18px; }
.ownmail-settings-field:last-child { margin-bottom: 0; }
.ownmail-settings-field > label {
    display: block;
    font-weight: 500;
    margin-bottom: 5px;
    font-size: 0.95em;
}
.ownmail-settings-field input[type="text"],
.ownmail-settings-field input[type="number"],
.ownmail-settings-field textarea,
.ownmail-settings-field select {
    width: 100%;
    box-sizing: border-box;
    padding: 8px 10px;
    border: 1px solid #ccc;
    border-radius: 4px;
    font-family: inherit;
    font-size: 0.95em;
}
.ownmail-settings-field input[type="number"] { width: 100px; }
.ownmail-settings-field textarea { resize: vertical; font-family: monospace; font-size: 0.85em; line-height: 1.7; }
.ownmail-settings-hint {
    font-size: 0.82em;
    color: #888;
    margin: 4px 0 0;
}
.ownmail-settings-checkbox label {
    display: flex;
    align-items: center;
    gap: 8px;
    font-weight: normal;
    cursor: pointer;
}
.ownmail-settings-checkbox input[type="checkbox"] {
    width: 16px;
    height: 16px;
    flex-shrink: 0;
}
.ownmail-settings-theme-options {
    display: flex;
    gap: 20px;
    margin-top: 4px;
}
.ownmail-settings-radio {
    display: flex;
    align-items: center;
    gap: 5px;
    font-weight: normal;
    cursor: pointer;
}
.ownmail-settings-actions {
    display: flex;
    gap: 12px;
    align-items: center;
    margin-top: 5px;
}
.ownmail-settings-save {
    background: #0066cc;
    color: #fff;
    border: none;
    padding: 10px 24px;
    border-radius: 5px;
    font-size: 0.95em;
    cursor: pointer;
    font-weight: 500;
}
.ownmail-settings-save:hover { background: #0052a3; }
.ownmail-settings-saved {
    background: #d4edda;
    border: 1px solid #c3e6cb;
    color: #155724;
    padding: 10px 14px;
    border-radius: 5px;
    font-size: 0.95em;
    margin-bottom: 5px;
    animation: ownmail-fade-out 0.6s ease 3s forwards;
}
@keyframes ownmail-fade-out {
    0% { opacity: 1; max-height: 50px; padding: 10px 14px; margin-bottom: 5px; }
    50% { opacity: 0; max-height: 50px; padding: 10px 14px; margin-bottom: 5px; }
    100% { opacity: 0; max-height: 0; padding: 0 14px; margin-bottom: 0; border-color: transparent; }
}

.ownmail-image-banner {
    background: #fff3cd;
    border: 1px solid #ffc107;
    border-radius: 5px;
    padding: 9px;
    margin: 15px;
    margin-top: 0;
    display: flex;
    flex-wrap: wrap;
    gap: 8px;
    justify-content: space-between;
    align-items: center;
    font-size: 0.9em;
    color: #664d03;
}
.ownmail-image-banner-text {
    flex: 1 1 auto;
}
.ownmail-image-banner-buttons {
    display: flex;
    gap: 8px;
    flex-shrink: 0;
}
.ownmail-image-banner button {
    padding: 6px 16px;
    background: #0066cc;
    color: white;
    border: none;
    border-radius: 3px;
    cursor: pointer;
    font-size: 0.95em;
    white-space: nowrap;
}
.ownmail-image-banner button:hover { background: #0052a3; }
.ownmail-image-banner .ownmail-trust-btn {
    background: #28a745;
}
.ownmail-image-banner .ownmail-trust-btn:hover {
    background: #218838;
}


/* Loading overlay */
.ownmail-loading-overlay {
    display: none;
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: rgba(255, 255, 255, 0.8);
    z-index: 9999;
    justify-content: center;
    align-items: center;
}
.ownmail-loading-overlay.ownmail-active { display: flex; }
.ownmail-loading-spinner {
    width: 40px;
    height: 40px;
    border: 4px solid #f3f3f3;
    border-top: 4px solid #0066cc;
    border-radius: 50%;
    animation: ownmail-spin 1s linear infinite;
}
@keyframes ownmail-spin {
    0% { transform: rotate(0deg); }
    100% { transform: rotate(360deg); }
}

/* Mobile responsive: 2-line layout */
@media screen and (max-width: 600px) {
    html, body {
        overflow-x: hidden;
        -webkit-text-size-adjust: 100%;
        text-size-adjust: 100%;
    }
    body {
        padding: 8px 0;
        padding-bottom: 15px;
    }
    .ownmail-header {
        padding: 0 10px;
    }
    .ownmail-sticky-header {
        padding: 8px 10px 5px 10px;
        margin-left: 0;
        margin-right: 0;
    }
    .ownmail-search-form {
        gap: 5px;
        box-sizing: border-box;
    }
    .ownmail-search-form input[type="text"] {
        padding: 8px 10px;
        min-width: 0;
    }
    .ownmail-search-form button {
        padding: 8px 12px;
        flex-shrink: 0;
    }
    .ownmail-sort-select {
        padding: 8px 6px;
        flex-shrink: 0;
    }
    .ownmail-results-header {
        flex-wrap: wrap;
    }
    .ownmail-results-header .ownmail-pagination { margin-left: auto; }
    .ownmail-email-list,
    .ownmail-email-detail,
    .ownmail-help-page,
    .ownmail-settings-page {
        border-radius: 0;
        border-left: none;
        border-right: none;
    }
    .ownmail-email-list {
        font-size: 0.95em;
    }
    .ownmail-email-detail,
    .ownmail-settings-page {
        padding: 10px;
        padding-bottom: 15px;
    }
    .ownmail-settings-section {
        padding: 12px;
    }
    .ownmail-email-row-link {
        display: grid;
        grid-template-columns: 1fr auto;
        grid-template-areas:
            "sender date"
            "content content";
        padding: 8px 10px 10px 10px;
        gap: 4px 10px;
    }
    .ownmail-email-sender {
        grid-area: sender;
        flex: none;
        max-width: none;
    }
    .ownmail-email-date {
        grid-area: date;
        flex: none;
        color: #666;
    }
    .ownmail-email-row-content {
        grid-area: content;
    }
    .ownmail-pagination {
        padding: 0 0 0 10px;
    }
    .ownmail-pagination-bottom {
        margin-right: 10px;
    }
}

/* Dark mode — applied via .ownmail-dark class on <html> */
html.ownmail-dark {
    a { color: #6cb6ff; }
    body {
        background: #1a1a1a;
        color: #e0e0e0;
    }
    .ownmail-header h1 a { color: #e0e0e0; }
    .ownmail-hamburger-dropdown {
        background: #2d2d2d;
        border-color: #444;
        box-shadow: 0 2px 10px rgba(0,0,0,0.4);
    }
    .ownmail-hamburger-dropdown a { color: #e0e0e0; }
    .ownmail-hamburger-dropdown a:hover { background: #3d3d3d; }
    .ownmail-hamburger-divider { border-top-color: #444; }
    .ownmail-stats { color: #999; }
    .ownmail-stats a { color: #6cb6ff; }
    .ownmail-sticky-header { background: #1a1a1a; }
    .ownmail-search-form input[type="text"] {
        background: #2d2d2d;
        border-color: #444;
        color: #e0e0e0;
    }
    .ownmail-search-form input[type="text"]::placeholder { color: #888; }
    .ownmail-sort-select {
        background: #2d2d2d;
        border-color: #444;
        color: #e0e0e0;
    }
    .ownmail-results-header { color: #999; }
    .ownmail-email-list, .ownmail-email-detail, .ownmail-help-page, .ownmail-settings-page {
        background: #242424;
        border-color: #333;
    }
    .ownmail-email-row { border-bottom-color: #333; }
    .ownmail-email-row:hover { background: #2d2d2d; }
    .ownmail-email-row-link { color: inherit; }
    .ownmail-email-sender { color: #e0e0e0; }
    .ownmail-email-subject { color: #e0e0e0; }
    .ownmail-email-snippet { color: #888; }
    .ownmail-email-snippet::before { color: #888; }
    .ownmail-email-date { color: #888; }
    .ownmail-email-header { border-bottom-color: #333; }
    .ownmail-email-header-label { color: #999; }
    .ownmail-email-content-area {
        background: #242424;
        display: flow-root;
    }
    /* Default: force light mode for HTML email content since most emails
       assume a white background.  The .ownmail-email-dark class overrides
       this when the email has its own dark mode CSS or dark backgrounds. */
    .ownmail-email-content-area:not(.ownmail-email-dark) #ownmail-email-content {
        background: #fff;
        color: #333;
        color-scheme: light;
        border-radius: 0 0 5px 5px;
    }
    /* When email supports dark mode natively, let it render naturally */
    .ownmail-email-content-area.ownmail-email-dark #ownmail-email-content {
        color-scheme: dark;
        border-radius: 0 0 5px 5px;
    }
    #ownmail-email-content.ownmail-email-content-plain {
        background: transparent !important;
        color: #e0e0e0 !important;
        color-scheme: dark;
    }
    .ownmail-email-body { color: #e0e0e0; }
    .ownmail-email-body a { color: #6cb6ff; }
    .ownmail-email-body .ownmail-email-header-label { color: #999; }
    .ownmail-clickable-header { color: #6cb6ff; }
    .ownmail-label {
        background: #1e3a5f;
        color: #6cb6ff;
    }
    .ownmail-label:hover { background: #264d7a; }
    .ownmail-attachments { border-top-color: #333; }
    .ownmail-attachment-item { border-bottom-color: #333; }
    .ownmail-attachment-item a { color: #6cb6ff; }
    .ownmail-help { color: #999; }
    .ownmail-help code { background: #2d2d2d; }
    .ownmail-help a { color: #6cb6ff; }
    .ownmail-help-page h3 { color: #e0e0e0; }
    .ownmail-help-table td { border-bottom-color: #333; }
    .ownmail-help-table td:first-child { background: #2d2d2d; }
    .ownmail-settings-page { color: #e0e0e0; }
    .ownmail-settings-config-path code { background: #2d2d2d; }
    .ownmail-settings-section { border-color: #444; }
    .ownmail-settings-field input[type="text"],
    .ownmail-settings-field input[type="number"],
    .ownmail-settings-field textarea,
    .ownmail-settings-field select {
        background: #2d2d2d;
        border-color: #444;
        color: #e0e0e0;
    }
    .ownmail-settings-save { background: #1a73e8; }
    .ownmail-settings-save:hover { background: #1557b0; }
    .ownmail-settings-saved {
        background: #1e3a2a;
        border-color: #2a5a3a;
        color: #7ee787;
    }
    .ownmail-search-error {
        background: #3d2020;
        border-color: #5c3030;
        color: #ff8080;
    }
    .ownmail-search-error code { background: #4d2525; }
    .ownmail-no-results { color: #999; }
    .ownmail-pagination { border-top-color: #333; }
    .ownmail-pagination a { color: #6cb6ff; }
    .ownmail-pagination .ownmail-current { color: #999; }
    .ownmail-pagination-bottom { color: #999; }
    .ownmail-loading-overlay { background: rgba(0, 0, 0, 0.8); }
    .ownmail-loading-spinner { border-color: #333; border-top-color: #6cb6ff; }
    .ownmail-email-menu-btn span { background: #999; }
    .ownmail-email-menu-btn:hover { background: #3d3d3d; }
    .ownmail-email-menu-dropdown {
        background: #2d2d2d;
        border-color: #444;
        box-shadow: 0 2px 10px rgba(0,0,0,0.4);
    }
    .ownmail-email-menu-dropdown a { color: #e0e0e0; }
    .ownmail-email-menu-dropdown a:hover { background: #3d3d3d; }
    .ownmail-email-menu-divider { border-top-color: #444; }
    .ownmail-image-banner {
        background: #4a3f00;
        border-color: #6b5a00;
        color: #f0e0a0;
    }
}

/* Print */
@media print {
    html.ownmail-dark { color-scheme: light; }
    html.ownmail-dark body { background: none; color: #333; }
    html.ownmail-dark .ownmail-email-detail { background: none; color: #333; }
    html.ownmail-dark .ownmail-email-header-label { color: #666; }
    html.ownmail-dark .ownmail-email-body { color: #333; }
    html.ownmail-dark .ownmail-email-content-area { background: none !important; }
    html.ownmail-dark #ownmail-email-content { background: none !important; color: #333 !important; }
    html.ownmail-dark .ownmail-attachments { border-top-color: #eee; }
    html.ownmail-dark .ownmail-attachment-item a { color: #333; }
    body { background: none; padding: 0; max-width: none; }
    .ownmail-header,
    .ownmail-hamburger,
    .ownmail-email-menu,
    .ownmail-image-banner,
    .ownmail-loading-overlay { display: none !important; }
    .ownmail-email-detail {
        border: none;
        box-shadow: none;
        padding: 0;
    }
    .ownmail-labels { display: none; }
    a { color: inherit; }
    .ownmail-email-content-area { border: none !important; }
    .ownmail-attachments { break-inside: avoid; }
}
